package com.muyu.domain.resp;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;

/**
 * 车辆基础信息列表响应对象
 * @Author：yang
 * @Package：com.muyu.domain.resq
 * @Project：cloud-server-8
 * @name：CarInformationResp
 * @Date：2024/9/28 12:08
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Tag(name = "车辆基础信息列表")
public class CarInformationResp {

    /**
     * 车辆ID
     */
    @TableId(value = "car_information_id",type = IdType.AUTO)
    private Long carInformationId;
    /**
     * 车辆唯一VIN
     */
//    @TableName(value = "car_information_VIN")
    @TableField(value = "car_information_VIN")
    private String carInformationVIN;
    /**
     * 车牌号
     */
    private String carInformationLicensePlate;
    /**
     * 车辆颜色
     */
    private String carInformationColor;
    /**
     * 车辆驾驶员
     */
    private String carInformationDriver;
    /**
     * 车辆电子围栏外键ID
     */
    private Integer carInformationFence;
    /**
     * 车检到期日期
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(locale="zh", timezone="GMT+8", pattern="yyyy-MM-dd")
    private Date carInformationExamineEnddata;
    /**
     * 车辆类型外键ID
     */
    private Integer carInformationType;
    /**
     * 车辆品牌
     */
    private String carInformationBrand;
    /**
     * 是否重点车辆 (0否默认 1是 )
     */
    private Integer carInformationFocus;

    /**
     * 车辆电机厂商
     */
    private String carInformationMotorManufacturer;

    /**
     * 车辆电机型号
     */
    private String carInformationMotorModel;

    /**
     * 车辆电池厂商
     */
    private String carInformationBatteryManufacturer;

    /**
     * 车辆电池型号
     */
    private String carInformationBatteryModel;

    /**
     * 启用状态(1.在线 2.离线 3.已断开 4.待连接 5.维修中)
     */
    private Integer carInformationState;

    //车辆类型表
    /**
     * 车辆类型ID
     */
    @TableField(value = "car_information_type")
    private Integer carTypeId;
    /**
     * 车辆类型名
     */
    @TableField(exist = false)
    private String carTypeName;
    /**
     * 车辆规则外键ID
     */
    private long carTypeRules;

    //电子围栏
    /**
     *电子围栏ID
     */
    private Integer id;

    /**
     * 电子围栏名
     */
    private String name;
}
