package com.muyu.server.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.muyu.domain.CarType;
import com.muyu.domain.WarnStrategy;
import com.muyu.domain.req.WarnStrategyReq;

import java.util.List;

/**
 * 预警策略业务层
 * @Author：蓬叁
 * @Package：com.muyu.warn.controller
 * @Project：cloud-server-8
 * @name：WarnLogsController
 * @Date：2024/9/20 下午7:29
 */
public interface WarnStrategyService extends IService<WarnStrategy> {
    /**
     * 精确查询预警策略
     *
     * @param id 预警策略主键
     * @return 预警策略
     */
    public WarnStrategy selectWarnStrategyById(Long id);

    /**
     * 查询预警策略列表
     *
     * @param warnStrategy 预警策略
     * @return 预警策略集合
     */
    public List<WarnStrategy> selectWarnStrategyList(WarnStrategy warnStrategy);

    /**
     * 判断 预警策略 id是否唯一
     * @param warnStrategy 预警策略
     * @return 结果
     */
    Boolean checkIdUnique(WarnStrategy warnStrategy);

    /**
     * 查找车辆类型
     * @return
     */
    List<CarType> findByCarType();
    /**
     * 根据Id查找车辆信息
     * @param ids
     * @return
     */
    List<WarnStrategyReq> selectStrategyType(Long ids);
}
